pub struct AnalyzerRegistry { /* private fields */ }Expand description
Dispatches to the first analyzer that accepts a blob.
Implementations
Sourceimpl AnalyzerRegistry
impl AnalyzerRegistry
Sourcepub fn with_defaults() -> Self
pub fn with_defaults() -> Self
Creates a registry with the default analyzers.
Sourcepub fn register(self, analyzer: Arc<dyn BlobAnalyzer>) -> Self
pub fn register(self, analyzer: Arc<dyn BlobAnalyzer>) -> Self
Registers another analyzer.
Sourcepub async fn analyze(
&self,
blob: &Blob,
data: &Bytes,
) -> Result<Analysis, AnalyzerError>
pub async fn analyze( &self, blob: &Blob, data: &Bytes, ) -> Result<Analysis, AnalyzerError>
Analyzes a blob with the first matching analyzer.
Errors
Returns an error when no analyzer accepts the blob or when the analyzer fails.
Sourcepub fn analyze_sync(
&self,
blob: &Blob,
data: &Bytes,
) -> Result<Analysis, AnalyzerError>
pub fn analyze_sync( &self, blob: &Blob, data: &Bytes, ) -> Result<Analysis, AnalyzerError>
Analyzes a blob with the first matching analyzer using the thread-local runtime.
Errors
Returns an error when no analyzer accepts the blob or when the analyzer fails.