Attachment

Struct Attachment 

pub struct Attachment { /* private fields */ }
Links a blob to a record instance.

Implementations

Source

impl Attachment

pub fn new( record_type: impl Into<String>, record_id: impl Into<String>, name: impl Into<String>, blob: Blob, ) -> Result<Self, AttachmentError>

Creates a new attachment.

Errors

Returns an error when the attachment name is empty.

pub fn id(&self) -> Uuid

Returns the attachment identifier.

pub fn record_type(&self) -> &str

Returns the owning record type.

pub fn record_id(&self) -> &str

Returns the owning record identifier.

pub fn name(&self) -> &str

Returns the attachment name.

pub fn blob(&self) -> &Blob

Returns the referenced blob.

pub fn blob_id(&self) -> Uuid

Returns the blob identifier.

pub fn created_at(&self) -> DateTime<Utc>

Returns the creation timestamp.

pub async fn purge<S: StorageService + ?Sized>( &self, service: &S, ) -> Result<(), AttachmentError>

Deletes the attached blob from storage.

Errors

Returns an error when the storage service delete fails.

pub fn purge_sync<S: StorageService + ?Sized>( &self, service: &S, ) -> Result<(), AttachmentError>

Deletes the attached blob from storage using the thread-local runtime.

Errors

Returns an error when the storage service delete fails.