pub struct ManyAttachments { /* private fields */ }Expand description
Represents a has_many_attached relation.
Implementations
Sourceimpl ManyAttachments
impl ManyAttachments
Sourcepub fn new(
record_type: impl Into<String>,
record_id: impl Into<String>,
name: impl Into<String>,
) -> Self
pub fn new( record_type: impl Into<String>, record_id: impl Into<String>, name: impl Into<String>, ) -> Self
Creates an empty collection attachment relation.
Sourcepub fn attach(&mut self, blob: Blob) -> Result<&Attachment, AttachmentError>
pub fn attach(&mut self, blob: Blob) -> Result<&Attachment, AttachmentError>
Sourcepub fn attach_many<I>(&mut self, blobs: I) -> Result<(), AttachmentError>where
I: IntoIterator<Item = Blob>,
pub fn attach_many<I>(&mut self, blobs: I) -> Result<(), AttachmentError>where
I: IntoIterator<Item = Blob>,
Appends several blobs to the collection.
Errors
Returns an error when any attachment cannot be built.
Sourcepub fn is_attached(&self) -> bool
pub fn is_attached(&self) -> bool
Returns whether at least one blob is attached.
Sourcepub fn attachments(&self) -> &[Attachment]
pub fn attachments(&self) -> &[Attachment]
Returns all attachments in insertion order.
Sourcepub fn blobs(&self) -> impl Iterator<Item = &Blob>
pub fn blobs(&self) -> impl Iterator<Item = &Blob>
Returns an iterator over the attached blobs.
Sourcepub fn detach_blob(&mut self, blob_id: Uuid) -> Option<Attachment>
pub fn detach_blob(&mut self, blob_id: Uuid) -> Option<Attachment>
Removes an attachment by blob id.
Sourcepub async fn purge_all<S: StorageService + ?Sized>(
&mut self,
service: &S,
) -> Result<Vec<Attachment>, AttachmentError>
pub async fn purge_all<S: StorageService + ?Sized>( &mut self, service: &S, ) -> Result<Vec<Attachment>, AttachmentError>
Purges all attached blobs from storage and clears the collection.
Errors
Returns an error when any storage delete fails.
Sourcepub fn purge_all_sync<S: StorageService + ?Sized>(
&mut self,
service: &S,
) -> Result<Vec<Attachment>, AttachmentError>
pub fn purge_all_sync<S: StorageService + ?Sized>( &mut self, service: &S, ) -> Result<Vec<Attachment>, AttachmentError>
Purges all attached blobs from storage and clears the collection using the thread-local runtime.
Errors
Returns an error when any storage delete fails.