pub struct OneAttachment { /* private fields */ }Expand description
Represents a has_one_attached relation.
Implementations
Sourceimpl OneAttachment
impl OneAttachment
Sourcepub fn new(
record_type: impl Into<String>,
record_id: impl Into<String>,
name: impl Into<String>,
) -> Self
pub fn new( record_type: impl Into<String>, record_id: impl Into<String>, name: impl Into<String>, ) -> Self
Creates an empty one-to-one attachment relation.
Sourcepub fn attach(&mut self, blob: Blob) -> Result<&Attachment, AttachmentError>
pub fn attach(&mut self, blob: Blob) -> Result<&Attachment, AttachmentError>
Attaches a blob, replacing any existing attachment.
Errors
Returns an error when the attachment cannot be built.
Sourcepub fn is_attached(&self) -> bool
pub fn is_attached(&self) -> bool
Returns whether a blob is currently attached.
Sourcepub fn attachment(&self) -> Option<&Attachment>
pub fn attachment(&self) -> Option<&Attachment>
Returns the current attachment, if any.
Sourcepub fn detach(&mut self) -> Option<Attachment>
pub fn detach(&mut self) -> Option<Attachment>
Removes the current attachment and returns it.
Sourcepub async fn purge<S: StorageService + ?Sized>(
&mut self,
service: &S,
) -> Result<Option<Attachment>, AttachmentError>
pub async fn purge<S: StorageService + ?Sized>( &mut self, service: &S, ) -> Result<Option<Attachment>, AttachmentError>
Purges the current attachment from storage and detaches it.
Errors
Returns an error when the storage service delete fails.
Sourcepub fn purge_sync<S: StorageService + ?Sized>(
&mut self,
service: &S,
) -> Result<Option<Attachment>, AttachmentError>
pub fn purge_sync<S: StorageService + ?Sized>( &mut self, service: &S, ) -> Result<Option<Attachment>, AttachmentError>
Purges the current attachment from storage and detaches it using the thread-local runtime.
Errors
Returns an error when the storage service delete fails.