pub struct DirectUploadManager { /* private fields */ }Expand description
Creates and verifies direct upload tokens.
Implementations
Sourceimpl DirectUploadManager
impl DirectUploadManager
Sourcepub fn new(secret: impl Into<Vec<u8>>) -> Self
pub fn new(secret: impl Into<Vec<u8>>) -> Self
Creates a new manager using the provided signing secret.
Sourcepub async fn prepare<S: StorageService + ?Sized>(
&self,
blob: Blob,
service: &S,
expires_in: Duration,
) -> Result<DirectUploadRequest, DirectUploadError>
pub async fn prepare<S: StorageService + ?Sized>( &self, blob: Blob, service: &S, expires_in: Duration, ) -> Result<DirectUploadRequest, DirectUploadError>
Prepares a direct upload request for a blob.
Errors
Returns an error when the storage service cannot generate an upload URL or the token cannot be signed.
Sourcepub fn prepare_sync<S: StorageService + ?Sized>(
&self,
blob: Blob,
service: &S,
expires_in: Duration,
) -> Result<DirectUploadRequest, DirectUploadError>
pub fn prepare_sync<S: StorageService + ?Sized>( &self, blob: Blob, service: &S, expires_in: Duration, ) -> Result<DirectUploadRequest, DirectUploadError>
Prepares a direct upload request for a blob using the thread-local runtime.
Errors
Returns an error when the storage service cannot generate an upload URL or the token cannot be signed.
Sourcepub fn verify(
&self,
token: &str,
now: DateTime<Utc>,
) -> Result<DirectUploadTokenClaims, DirectUploadError>
pub fn verify( &self, token: &str, now: DateTime<Utc>, ) -> Result<DirectUploadTokenClaims, DirectUploadError>