Preview

Struct Preview 

pub struct Preview { /* private fields */ }
Preview artifact metadata.

Implementations

Source

impl Preview

pub fn new(blob: Blob) -> Self

Creates a preview placeholder for a blob.

pub fn blob(&self) -> &Blob

Returns the source blob.

pub fn key(&self) -> &str

Returns the preview storage key.

pub fn filename(&self) -> &str

Returns the preview filename.

pub fn content_type(&self) -> &str

Returns the preview content type.

pub async fn is_processed<S: StorageService + ?Sized>( &self, service: &S, ) -> Result<bool, PreviewError>

Returns whether the preview has been stored already.

Errors

Returns an error when the storage existence check fails.

pub fn is_processed_sync<S: StorageService + ?Sized>( &self, service: &S, ) -> Result<bool, PreviewError>

Returns whether the preview has been stored already using the thread-local runtime.

Errors

Returns an error when the storage existence check fails.

pub async fn processed<S: StorageService + ?Sized>( &self, service: &S, data: Bytes, ) -> Result<Self, PreviewError>

Stores preview bytes when missing.

Errors

Returns an error when the storage upload fails.

pub fn processed_sync<S: StorageService + ?Sized>( &self, service: &S, data: Bytes, ) -> Result<Self, PreviewError>

Stores preview bytes when missing using the thread-local runtime.

Errors

Returns an error when the storage upload fails.

pub async fn url<S: StorageService + ?Sized>( &self, service: &S, expires_in: Duration, ) -> Result<Url, PreviewError>

Generates a preview URL.

Errors

Returns an error when the storage service cannot build a URL.

pub fn url_sync<S: StorageService + ?Sized>( &self, service: &S, expires_in: Duration, ) -> Result<Url, PreviewError>

Generates a preview URL using the thread-local runtime.

Errors

Returns an error when the storage service cannot build a URL.