pub struct PreviewRegistry { /* private fields */ }Expand description
Registry of previewers.
Implementations
Sourceimpl PreviewRegistry
impl PreviewRegistry
Sourcepub fn with_defaults() -> Self
pub fn with_defaults() -> Self
Creates a registry with the default previewers.
Sourcepub async fn generate<S: StorageService + ?Sized>(
&self,
blob: Blob,
source: &Bytes,
service: &S,
) -> Result<Preview, PreviewError>
pub async fn generate<S: StorageService + ?Sized>( &self, blob: Blob, source: &Bytes, service: &S, ) -> Result<Preview, PreviewError>
Generates a preview using the first matching previewer.
Errors
Returns an error when no previewer accepts the blob.
Sourcepub fn generate_sync<S: StorageService + ?Sized>(
&self,
blob: Blob,
source: &Bytes,
service: &S,
) -> Result<Preview, PreviewError>
pub fn generate_sync<S: StorageService + ?Sized>( &self, blob: Blob, source: &Bytes, service: &S, ) -> Result<Preview, PreviewError>
Generates a preview using the first matching previewer with the thread-local runtime.
Errors
Returns an error when no previewer accepts the blob.