pub struct DiskService { /* private fields */ }Expand description
Stores objects on the local filesystem.
Implementations
Sourceimpl DiskService
impl DiskService
Sourcepub fn new(
name: impl Into<String>,
root: impl Into<PathBuf>,
) -> Result<Self, StorageError>
pub fn new( name: impl Into<String>, root: impl Into<PathBuf>, ) -> Result<Self, StorageError>
Creates a disk service rooted at the given path.
Errors
Returns an error when the default base URL cannot be constructed.
Sourcepub fn with_base_url(self, base_url: Url) -> Self
pub fn with_base_url(self, base_url: Url) -> Self
Returns a copy with a custom public base URL.