pub struct SignedUrlGenerator { /* private fields */ }Expand description
Signs and verifies blob and variant URLs.
Implementations
Sourceimpl SignedUrlGenerator
impl SignedUrlGenerator
Sourcepub fn new(
base_url: impl AsRef<str>,
secret: impl Into<Vec<u8>>,
) -> Result<Self, SignedUrlError>
pub fn new( base_url: impl AsRef<str>, secret: impl Into<Vec<u8>>, ) -> Result<Self, SignedUrlError>
Sourcepub fn variant_url(
&self,
variant: &Variant,
expires_in: Duration,
) -> Result<Url, SignedUrlError>
pub fn variant_url( &self, variant: &Variant, expires_in: Duration, ) -> Result<Url, SignedUrlError>
Sourcepub fn redirect_url(
&self,
location: &Url,
expires_in: Duration,
) -> Result<Url, SignedUrlError>
pub fn redirect_url( &self, location: &Url, expires_in: Duration, ) -> Result<Url, SignedUrlError>
Sourcepub fn verify(&self, url: &Url) -> Result<SignedResource, SignedUrlError>
pub fn verify(&self, url: &Url) -> Result<SignedResource, SignedUrlError>
Verifies a signed URL at the current time.
Errors
Returns an error when the signature is invalid, the payload cannot be decoded, or the URL has expired.
Sourcepub fn verify_at(
&self,
url: &Url,
now: DateTime<Utc>,
) -> Result<SignedResource, SignedUrlError>
pub fn verify_at( &self, url: &Url, now: DateTime<Utc>, ) -> Result<SignedResource, SignedUrlError>
Verifies a signed URL at the supplied instant.
Errors
Returns an error when the signature is invalid, the payload cannot be decoded, or the URL has expired.