Variant

Struct Variant 

pub struct Variant { /* private fields */ }
Describes a transformable blob representation.

Implementations

Source

impl Variant

pub fn new(blob: Blob, transformations: BTreeMap<String, Value>) -> Self

Creates a new variant request.

pub fn blob(&self) -> &Blob

Returns the source blob.

pub fn key(&self) -> &str

Returns the variant cache key.

pub fn filename(&self) -> &str

Returns the normalized output filename.

pub fn content_type(&self) -> Option<&str>

Returns the output content type.

pub fn transformations(&self) -> &BTreeMap<String, Value>

Returns the canonical transformations.

pub fn is_variable(&self) -> bool

Returns whether the source blob can be transformed.

pub async fn is_processed<S: StorageService + ?Sized>( &self, service: &S, ) -> Result<bool, VariantError>

Returns whether the variant has already been processed.

Errors

Returns an error when the storage backend existence check fails.

pub fn is_processed_sync<S: StorageService + ?Sized>( &self, service: &S, ) -> Result<bool, VariantError>

Returns whether the variant has already been processed using the thread-local runtime.

Errors

Returns an error when the storage backend existence check fails.

pub async fn processed<S: StorageService + ?Sized>( &self, service: &S, ) -> Result<Self, VariantError>

Processes the variant and stores a cached placeholder object when missing.

Errors

Returns an error when the blob cannot be transformed or the storage backend fails.

pub fn processed_sync<S: StorageService + ?Sized>( &self, service: &S, ) -> Result<Self, VariantError>

Processes the variant and stores a cached placeholder object when missing using the thread-local runtime.

Errors

Returns an error when the blob cannot be transformed or the storage backend fails.

pub async fn url<S: StorageService + ?Sized>( &self, service: &S, expires_in: Duration, ) -> Result<Url, VariantError>

Generates a storage-backed URL for the processed variant.

Errors

Returns an error when the storage backend cannot generate the URL.

pub fn url_sync<S: StorageService + ?Sized>( &self, service: &S, expires_in: Duration, ) -> Result<Url, VariantError>

Generates a storage-backed URL for the processed variant using the thread-local runtime.

Errors

Returns an error when the storage backend cannot generate the URL.