pub struct Attachment { /* private fields */ }Expand description
Links a blob to a record instance.
Implementations
Sourceimpl Attachment
impl Attachment
Sourcepub fn new(
record_type: impl Into<String>,
record_id: impl Into<String>,
name: impl Into<String>,
blob: Blob,
) -> Result<Self, AttachmentError>
pub fn new( record_type: impl Into<String>, record_id: impl Into<String>, name: impl Into<String>, blob: Blob, ) -> Result<Self, AttachmentError>
Sourcepub fn record_type(&self) -> &str
pub fn record_type(&self) -> &str
Returns the owning record type.
Sourcepub fn created_at(&self) -> DateTime<Utc>
pub fn created_at(&self) -> DateTime<Utc>
Returns the creation timestamp.
Sourcepub async fn purge<S: StorageService + ?Sized>(
&self,
service: &S,
) -> Result<(), AttachmentError>
pub async fn purge<S: StorageService + ?Sized>( &self, service: &S, ) -> Result<(), AttachmentError>
Deletes the attached blob from storage.
Errors
Returns an error when the storage service delete fails.
Sourcepub fn purge_sync<S: StorageService + ?Sized>(
&self,
service: &S,
) -> Result<(), AttachmentError>
pub fn purge_sync<S: StorageService + ?Sized>( &self, service: &S, ) -> Result<(), AttachmentError>
Deletes the attached blob from storage using the thread-local runtime.
Errors
Returns an error when the storage service delete fails.