pub struct Preview { /* private fields */ }Expand description
Preview artifact metadata.
Implementations
Sourceimpl Preview
impl Preview
Sourcepub fn content_type(&self) -> &str
pub fn content_type(&self) -> &str
Returns the preview content type.
Sourcepub async fn is_processed<S: StorageService + ?Sized>(
&self,
service: &S,
) -> Result<bool, PreviewError>
pub async fn is_processed<S: StorageService + ?Sized>( &self, service: &S, ) -> Result<bool, PreviewError>
Returns whether the preview has been stored already.
Errors
Returns an error when the storage existence check fails.
Sourcepub fn is_processed_sync<S: StorageService + ?Sized>(
&self,
service: &S,
) -> Result<bool, PreviewError>
pub fn is_processed_sync<S: StorageService + ?Sized>( &self, service: &S, ) -> Result<bool, PreviewError>
Returns whether the preview has been stored already using the thread-local runtime.
Errors
Returns an error when the storage existence check fails.
Sourcepub async fn processed<S: StorageService + ?Sized>(
&self,
service: &S,
data: Bytes,
) -> Result<Self, PreviewError>
pub async fn processed<S: StorageService + ?Sized>( &self, service: &S, data: Bytes, ) -> Result<Self, PreviewError>
Sourcepub fn processed_sync<S: StorageService + ?Sized>(
&self,
service: &S,
data: Bytes,
) -> Result<Self, PreviewError>
pub fn processed_sync<S: StorageService + ?Sized>( &self, service: &S, data: Bytes, ) -> Result<Self, PreviewError>
Stores preview bytes when missing using the thread-local runtime.
Errors
Returns an error when the storage upload fails.
Sourcepub async fn url<S: StorageService + ?Sized>(
&self,
service: &S,
expires_in: Duration,
) -> Result<Url, PreviewError>
pub async fn url<S: StorageService + ?Sized>( &self, service: &S, expires_in: Duration, ) -> Result<Url, PreviewError>
Sourcepub fn url_sync<S: StorageService + ?Sized>(
&self,
service: &S,
expires_in: Duration,
) -> Result<Url, PreviewError>
pub fn url_sync<S: StorageService + ?Sized>( &self, service: &S, expires_in: Duration, ) -> Result<Url, PreviewError>
Generates a preview URL using the thread-local runtime.
Errors
Returns an error when the storage service cannot build a URL.